==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/Image/Image.base.js <==
import '../node_modules/core-js/modules/es.date.to-string.js';
import '../node_modules/core-js/modules/es.object.to-string.js';
import '../node_modules/core-js/modules/es.reflect.construct.js';
import '../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import '../node_modules/core-js/modules/es.number.constructor.js';
import _mergeJSXProps from '../node_modules/@vue/babel-helper-vue-jsx-merge-props/dist/helper.js';
import { ImageLoadState, ImageCoverStyle, ImageFit } from './Image.types.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();

var ImageBase = function (_BaseComponent) {
  _inherits(ImageBase, _BaseComponent);

  var _super = _createSuper(ImageBase);

  function ImageBase() {
    var _this;

    _classCallCheck(this, ImageBase);

    _this = _super.apply(this, arguments);
    _this.loadState = ImageLoadState.notLoaded;
    return _this;
  }

  _createClass(ImageBase, [{
    key: "render",
    value: function render() {
      var h = arguments[0];
      var classNames = this.classNames,
          src = this.src,
          alt = this.alt,
          width = this.width,
          height = this.height;
      return h("div", {
        "class": classNames.root,
        "style": {
          width: width + 'px',
          height: height + 'px'
        }
      }, [h("img", _mergeJSXProps([{}, this.$attrs, {
        "class": classNames.image,
        "attrs": {
          "src": src,
          "alt": alt
        },
        "on": {
          "load": this.onImageLoaded,
          "error": this.onImageError
        }
      }]))]);
    }
  }, {
    key: "onImageLoaded",
    value: function onImageLoaded() {
      this.loadState = ImageLoadState.loaded;
    }
  }, {
    key: "onImageError",
    value: function onImageError() {
      this.loadState = ImageLoadState.error;
    }
  }, {
    key: "classNames",
    get: function get() {
      var styles = this.styles,
          loadState = this.loadState,
          coverStyle = this.coverStyle,
          imageFit = this.imageFit,
          theme = this.theme,
          className = this.className,
          width = this.width,
          height = this.height,
          maximizeFrame = this.maximizeFrame,
          shouldFadeIn = this.shouldFadeIn,
          shouldStartVisible = this.shouldStartVisible;
      return getClassNames(styles, {
        theme: theme,
        className: className,
        width: width,
        height: height,
        maximizeFrame: maximizeFrame,
        shouldFadeIn: shouldFadeIn,
        shouldStartVisible: shouldStartVisible,
        isLoaded: loadState === ImageLoadState.loaded || loadState === ImageLoadState.notLoaded && shouldStartVisible,
        isLandscape: coverStyle === ImageCoverStyle.landscape,
        isCenter: imageFit === ImageFit.center,
        isCenterContain: imageFit === ImageFit.centerContain,
        isCenterCover: imageFit === ImageFit.centerCover,
        isContain: imageFit === ImageFit.contain,
        isCover: imageFit === ImageFit.cover,
        isNone: imageFit === ImageFit.none,
        isError: loadState === ImageLoadState.error,
        isNotImageFit: imageFit == null
      });
    }
  }]);

  return ImageBase;
}(BaseComponent);

ImageBase.svgRegex = /\.svg$/i;

__decorate([Prop({
  type: String,
  required: true
}), __metadata("design:type", String)], ImageBase.prototype, "src", void 0);

__decorate([Prop({
  type: String,
  "default": ''
}), __metadata("design:type", String)], ImageBase.prototype, "alt", void 0);

__decorate([Prop({
  type: [String, Number],
  "default": ''
}), __metadata("design:type", Object)], ImageBase.prototype, "width", void 0);

__decorate([Prop({
  type: [String, Number],
  "default": ''
}), __metadata("design:type", Object)], ImageBase.prototype, "height", void 0);

__decorate([Prop({
  type: Number,
  "default": null
}), __metadata("design:type", Number)], ImageBase.prototype, "imageFit", void 0);

__decorate([Prop({
  type: Boolean,
  "default": null
}), __metadata("design:type", Boolean)], ImageBase.prototype, "maximizeFrame", void 0);

__decorate([Prop({
  type: Boolean,
  "default": true
}), __metadata("design:type", Boolean)], ImageBase.prototype, "shouldFadeIn", void 0);

__decorate([Prop({
  type: Boolean,
  "default": null
}), __metadata("design:type", Boolean)], ImageBase.prototype, "shouldStartVisible", void 0);

__decorate([Prop({
  type: Number,
  "default": ImageCoverStyle.portrait
}), __metadata("design:type", Number)], ImageBase.prototype, "coverStyle", void 0);

ImageBase = __decorate([Component({
  inheritAttrs: false
})], ImageBase);

export { ImageBase };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/Image/Image.base.js <==
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import 'core-js/modules/es.number.constructor';
import _mergeJSXProps from '@vue/babel-helper-vue-jsx-merge-props';
import { ImageLoadState, ImageCoverStyle, ImageFit } from './Image.types.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();

var ImageBase = function (_BaseComponent) {
  _inherits(ImageBase, _BaseComponent);

  var _super = _createSuper(ImageBase);

  function ImageBase() {
    var _this;

    _classCallCheck(this, ImageBase);

    _this = _super.apply(this, arguments);
    _this.loadState = ImageLoadState.notLoaded;
    return _this;
  }

  _createClass(ImageBase, [{
    key: "render",
    value: function render() {
      var h = arguments[0];
      var classNames = this.classNames,
          src = this.src,
          alt = this.alt,
          width = this.width,
          height = this.height;
      return h("div", {
        "class": classNames.root,
        "style": {
          width: width + 'px',
          height: height + 'px'
        }
      }, [h("img", _mergeJSXProps([{}, this.$attrs, {
        "class": classNames.image,
        "attrs": {
          "src": src,
          "alt": alt
        },
        "on": {
          "load": this.onImageLoaded,
          "error": this.onImageError
        }
      }]))]);
    }
  }, {
    key: "onImageLoaded",
    value: function onImageLoaded() {
      this.loadState = ImageLoadState.loaded;
    }
  }, {
    key: "onImageError",
    value: function onImageError() {
      this.loadState = ImageLoadState.error;
    }
  }, {
    key: "classNames",
    get: function get() {
      var styles = this.styles,
          loadState = this.loadState,
          coverStyle = this.coverStyle,
          imageFit = this.imageFit,
          theme = this.theme,
          className = this.className,
          width = this.width,
          height = this.height,
          maximizeFrame = this.maximizeFrame,
          shouldFadeIn = this.shouldFadeIn,
          shouldStartVisible = this.shouldStartVisible;
      return getClassNames(styles, {
        theme: theme,
        className: className,
        width: width,
        height: height,
        maximizeFrame: maximizeFrame,
        shouldFadeIn: shouldFadeIn,
        shouldStartVisible: shouldStartVisible,
        isLoaded: loadState === ImageLoadState.loaded || loadState === ImageLoadState.notLoaded && shouldStartVisible,
        isLandscape: coverStyle === ImageCoverStyle.landscape,
        isCenter: imageFit === ImageFit.center,
        isCenterContain: imageFit === ImageFit.centerContain,
        isCenterCover: imageFit === ImageFit.centerCover,
        isContain: imageFit === ImageFit.contain,
        isCover: imageFit === ImageFit.cover,
        isNone: imageFit === ImageFit.none,
        isError: loadState === ImageLoadState.error,
        isNotImageFit: imageFit == null
      });
    }
  }]);

  return ImageBase;
}(BaseComponent);

ImageBase.svgRegex = /\.svg$/i;

__decorate([Prop({
  type: String,
  required: true
}), __metadata("design:type", String)], ImageBase.prototype, "src", void 0);

__decorate([Prop({
  type: String,
  default: ''
}), __metadata("design:type", String)], ImageBase.prototype, "alt", void 0);

__decorate([Prop({
  type: [String, Number],
  default: ''
}), __metadata("design:type", Object)], ImageBase.prototype, "width", void 0);

__decorate([Prop({
  type: [String, Number],
  default: ''
}), __metadata("design:type", Object)], ImageBase.prototype, "height", void 0);

__decorate([Prop({
  type: Number,
  default: null
}), __metadata("design:type", Number)], ImageBase.prototype, "imageFit", void 0);

__decorate([Prop({
  type: Boolean,
  default: null
}), __metadata("design:type", Boolean)], ImageBase.prototype, "maximizeFrame", void 0);

__decorate([Prop({
  type: Boolean,
  default: true
}), __metadata("design:type", Boolean)], ImageBase.prototype, "shouldFadeIn", void 0);

__decorate([Prop({
  type: Boolean,
  default: null
}), __metadata("design:type", Boolean)], ImageBase.prototype, "shouldStartVisible", void 0);

__decorate([Prop({
  type: Number,
  default: ImageCoverStyle.portrait
}), __metadata("design:type", Number)], ImageBase.prototype, "coverStyle", void 0);

ImageBase = __decorate([Component({
  inheritAttrs: false
})], ImageBase);

export { ImageBase };
